@@ -26,7 +26,6 @@
 #include "rsettingswidget.h"
 
 #include <QDebug>
-#include <KStandardDirs>
 
 #include "cantor_macros.h"
 #include <QMessageBox>
@@ -67,7 +66,7 @@ Cantor::Backend::Capabilities RBackend::capabilities() const
 
 bool RBackend::requirementsFullfilled() const
 {
-    QFileInfo info(KStandardDirs::findExe( QLatin1String("cantor_rserver") ) );
+    QFileInfo info(QStandardPaths::findExecutable( QLatin1String("cantor_rserver") ) );
     return info.isExecutable();
 }
 
@@ -81,10 +80,10 @@ KConfigSkeleton* RBackend::config() const
     return RServerSettings::self();
 }
 
-KUrl RBackend::helpUrl() const
+QUrl RBackend::helpUrl() const
 {
-    return i18nc("the url to the documentation of R, please check if there is a translated version and use the correct url",
-                 "http://rwiki.sciviews.org/doku.php?id=rdoc:rdoc" );
+    return QUrl(i18nc("the url to the documentation of R, please check if there is a translated version and use the correct url",
+                 "http://rwiki.sciviews.org/doku.php?id=rdoc:rdoc"));
 }
 
 QString RBackend::description() const
