@@ -30,13 +30,15 @@
 #include "latexresult.h"
 #include "settings.h"
 
+#include <QDir>
+#include <QTemporaryFile>
+
 #include <KLocale>
-#include <KUrl>
-#include <KTemporaryFile>
 #include <QDebug>
 #include <QTimer>
 #include <QRegExp>
 #include <QChar>
+#include <QUrl>
 
 MaximaExpression::MaximaExpression( Cantor::Session* session ) : Cantor::Expression(session)
 {
@@ -71,12 +73,10 @@ void MaximaExpression::evaluate()
     if(command().contains(QRegExp(QLatin1String("(?:plot2d|plot3d)\\s*\\([^\\)]"))) && MaximaSettings::self()->integratePlots() && !command().contains(QLatin1String("ps_file")))
     {
         m_isPlot=true;
-        m_tempFile=new KTemporaryFile();
-        m_tempFile->setPrefix( QLatin1String("cantor_maxima-" ));
 #ifdef WITH_EPS
-        m_tempFile->setSuffix( QLatin1String(".eps" ));
+        m_tempFile=new QTemporaryFile(QDir::tempPath() + QLatin1String("/cantor_maxima-XXXXXX.eps" ));
 #else
-        m_tempFile->setSuffix( QLatin1String(".png" ));
+        m_tempFile=new QTemporaryFile(QDir::tempPath() + QLatin1String("/cantor_maxima-XXXXXX.png"));
 #endif
         m_tempFile->open();
 
@@ -328,13 +328,9 @@ bool MaximaExpression::parseOutput(QString& out)
 {
     enum ParserStatus{ReadingOpeningTag, ReadingClosingTag, ReadingText};
     int idx=0;
-    ParserStatus status;
-    QStringRef tagName;
 
     qDebug()<<"attempting to parse "<<out;
 
-    QChar c;
-
     int numResults=0;
     QString textBuffer;
     QString latexBuffer;
@@ -631,9 +627,9 @@ void MaximaExpression::imageChanged()
     if(m_tempFile->size()>0)
     {
 #ifdef WITH_EPS
-        setResult( new Cantor::EpsResult( KUrl(m_tempFile->fileName()) ) );
+        setResult( new Cantor::EpsResult( QUrl::fromLocalFile(m_tempFile->fileName()) ) );
 #else
-        setResult( new Cantor::ImageResult( KUrl(m_tempFile->fileName()) ) );
+        setResult( new Cantor::ImageResult( QUrl::fromLocalFile(m_tempFile->fileName()) ) );
 #endif
         setStatus(Cantor::Expression::Done);
     }
