@@ -30,15 +30,13 @@
 #include <KMessageBox>
 #include <KStandardAction>
 #include <KStatusBar>
-#include <KUrl>
 #include <QIcon>
 #include <KLocale>
-#include <KTabWidget>
+#include <QTabWidget>
 #include <KConfigDialog>
 #include <KTextEdit>
-#include <KTextBrowser>
+#include <QTextBrowser>
 #include <KXMLGUIFactory>
-#include <KStandardDirs>
 #include <KToggleAction>
 #include <QMenu>
 
@@ -48,6 +46,8 @@
 #include <QDebug>
 #include <QDockWidget>
 #include <QDir>
+#include <QPushButton>
+#include <KConfigGroup>
 
 #include "lib/backend.h"
 #include "lib/panelpluginhandler.h"
@@ -71,14 +71,14 @@ CantorShell::CantorShell()
 
     createGUI(0);
 
-    m_tabWidget=new KTabWidget(this);
+    m_tabWidget=new QTabWidget(this);
     m_tabWidget->setTabsClosable(true);
     m_tabWidget->setMovable(true);
     m_tabWidget->setDocumentMode(true);
     setCentralWidget(m_tabWidget);
 
     connect(m_tabWidget, SIGNAL(currentChanged(int)), this, SLOT(activateWorksheet(int)));
-    connect(m_tabWidget, SIGNAL(closeRequest (QWidget *)), this, SLOT(closeTab(QWidget*)));
+    connect(m_tabWidget, SIGNAL(tabCloseRequested(int)), this, SLOT(closeTab(int)));
 
     // apply the saved mainwindow settings, if any, and ask the mainwindow
     // to automatically save settings if changed: window size, toolbar
@@ -93,7 +93,7 @@ CantorShell::~CantorShell()
 
 }
 
-void CantorShell::load(const KUrl& url)
+void CantorShell::load(const QUrl &url)
 {
     if (!m_part||!m_part->url().isEmpty() || m_part->isModified() )
     {
@@ -188,7 +188,7 @@ void CantorShell::fileOpen()
     // this slot is called whenever the File->Open menu is selected,
     // the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
     // button is clicked
-    KUrl url = KFileDialog::getOpenUrl( KUrl(), i18n("*.cws|Cantor Worksheet"), this );
+    QUrl url = KFileDialog::getOpenUrl( QUrl(), i18n("*.cws|Cantor Worksheet"), this );
 
     if (url.isEmpty() == false)
     {
@@ -235,7 +235,7 @@ void CantorShell::addWorksheet()
 
     }else
     {
-        KTextBrowser *browser=new KTextBrowser(this);
+        QTextBrowser *browser=new QTextBrowser(this);
         QString backendList=QLatin1String("<ul>");
         int backendListSize = 0;
         foreach(Cantor::Backend* b, Cantor::Backend::availableBackends())
@@ -339,17 +339,29 @@ void CantorShell::setTabCaption(const QString& caption)
     m_tabWidget->setTabText(m_tabWidget->indexOf(part->widget()), caption);
 }
 
-void CantorShell::closeTab(QWidget* widget)
+void CantorShell::closeTab(int index)
 {
-    if(widget==0)
+    if (!reallyClose(false))
     {
-        if(m_part!=0)
-            widget=m_part->widget();
-        else
-            return;
+        return;
+    }
+
+    QWidget* widget = nullptr;
+    if (index >= 0)
+    {
+        widget = m_tabWidget->widget(index);
+    }
+    else if (m_part)
+    {
+        widget = m_part->widget();
+    }
+
+    if (!widget)
+    {
+        qWarning() << "Could not find widget by tab index" << index;
+        return;
     }
 
-    int index=m_tabWidget->indexOf(widget);
 
     m_tabWidget->removeTab(index);
 
@@ -367,6 +379,57 @@ void CantorShell::closeTab(QWidget* widget)
     }
 }
 
+bool CantorShell::reallyClose(bool checkAllParts) {
+    if(checkAllParts && m_parts.count() > 1) {
+        bool modified = false;
+         foreach( KParts::ReadWritePart* const part, m_parts)
+        {
+            if(part->isModified()) {
+                modified = true;
+                break;
+            }
+        }
+        if(!modified) return true;
+        int want_save = KMessageBox::warningYesNo( this,
+            i18n("Multiple unsaved Worksheets are opened do want to close?"),
+            i18n("Close Cantor"));
+        switch (want_save) {
+            case KMessageBox::Yes:
+                return true;
+            case KMessageBox::No:
+                return false;
+        }
+    }
+    if (m_part && m_part->isModified() ) {
+        int want_save = KMessageBox::warningYesNoCancel( this,
+            i18n("The current project has been modified. Do you want to save it?"),
+            i18n("Save Project"));
+        switch (want_save) {
+            case KMessageBox::Yes:
+                m_part->save();
+                if(m_part->waitSaveComplete()) {
+                    return true;
+                } else {
+                    m_part->setModified(true);
+                    return false;
+                }
+            case KMessageBox::Cancel:
+                return false;
+            case KMessageBox::No:
+                return true;
+        }
+    }
+    return true;
+}
+
+void CantorShell::closeEvent(QCloseEvent* event) {
+    if(!reallyClose()) {
+        event->ignore();
+    } else {
+        KParts::MainWindow::closeEvent(event);
+    }
+}
+
 void CantorShell::showSettings()
 {
     KConfigDialog *dialog = new KConfigDialog(this,  QLatin1String("settings"), Settings::self());
@@ -397,12 +460,12 @@ void CantorShell::downloadExamples()
 
 void CantorShell::openExample()
 {
-    QString dir = KStandardDirs::locateLocal("appdata",  QLatin1String("examples"));
+    QString dir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/examples");
     if (dir.isEmpty()) return;
     QDir().mkpath(dir);
 
     QStringList files=QDir(dir).entryList(QDir::Files);
-    QPointer<KDialog> dlg=new KDialog(this);
+    QPointer<QDialog> dlg=new QDialog(this);
     QListWidget* list=new QListWidget(dlg);
     foreach(const QString& file, files)
     {
@@ -411,14 +474,24 @@ void CantorShell::openExample()
         list->addItem(name);
     }
 
-    dlg->setMainWidget(list);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    dlg->setLayout(mainLayout);
+    mainLayout->addWidget(list);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+
+    mainLayout->addWidget(buttonBox);
+
+    buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
+    buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
+
+    connect(buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()) );
+    connect(buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()) );
 
     if (dlg->exec()==QDialog::Accepted&&list->currentRow()>=0)
     {
         const QString& selectedFile=files[list->currentRow()];
-        KUrl url;
-        url.setDirectory(dir);
-        url.setFileName(selectedFile);
+        QUrl url = QUrl::fromLocalFile(QDir(dir).absoluteFilePath(selectedFile));
 
         qDebug()<<"loading file "<<url;
         load(url);
