@@ -26,9 +26,8 @@
 #include <QList>
 
 #include <KParts/ReadWritePart>
-#include <KUrl>
 
-class KTabWidget;
+class QTabWidget;
 class KTextEdit;
 
 /**
@@ -52,7 +51,7 @@ public:
     /**
      * Use this method to load whatever file/URL you have
      */
-    void load(const KUrl& url);
+    void load(const QUrl& url);
 
     /**
      * checks if at least one usable Backend is installed
@@ -84,7 +83,7 @@ private Q_SLOTS:
     void activateWorksheet(int index);
 
     void setTabCaption(const QString& tab);
-    void closeTab(QWidget* widget = 0);
+    void closeTab(int index = -1);
 
     void showSettings();
 
@@ -94,12 +93,14 @@ private Q_SLOTS:
     void updatePanel();
 private:
     void setupActions();
+    void closeEvent(QCloseEvent*);
+    bool reallyClose(bool checkAllParts = true);
     KParts::ReadWritePart* findPart(QWidget* widget);
 
 private:
     QList<KParts::ReadWritePart *> m_parts;
     KParts::ReadWritePart* m_part;
-    KTabWidget* m_tabWidget;
+    QTabWidget* m_tabWidget;
     QList<QDockWidget*> m_panels;
     QDockWidget* m_helpDocker;
 };
