@@ -27,7 +27,7 @@
 #include "lib/animationresult.h"
 
 #include <KGlobal>
-#include <KStandardDirs>
+#include <QDir>
 
 LoadedExpression::LoadedExpression( Cantor::Session* session ) : Cantor::Expression( session )
 {
@@ -66,9 +66,9 @@ void LoadedExpression::loadFromXml(const QDomElement& xml, const KZip& file)
         if (imageEntry&&imageEntry->isFile())
         {
             const KArchiveFile* imageFile=static_cast<const KArchiveFile*>(imageEntry);
-            QString dir=KGlobal::dirs()->saveLocation("tmp", QLatin1String("cantor/"));
+            QString dir=QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QLatin1String("/") + QLatin1String("cantor");
             imageFile->copyTo(dir);
-            KUrl imageUrl=QString(dir + QLatin1Char('/') + imageFile->name());
+            QUrl imageUrl = QUrl::fromLocalFile(QDir(dir).absoluteFilePath(imageFile->name()));
             if(type==QLatin1String("latex"))
             {
                 result=new Cantor::LatexResult(resultElement.text(), imageUrl);
